<%--
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */
--%>

<%@ include file="/init.jsp" %>

<%
String from = ParamUtil.getString(request, "from");

if (!CurrencyConverterUtil.isCurrency(from)) {
	from = CurrencyConverter.DEFAULT_FROM;
}

String to = ParamUtil.getString(request, "to");

if (!CurrencyConverterUtil.isCurrency(to)) {
	to = CurrencyConverter.DEFAULT_TO;
}

CurrencyConverter currencyConverter = CurrencyConverterUtil.getCurrencyConverter(from + to);

double number = ParamUtil.getDouble(request, "number", 1.0);

String chartId = ParamUtil.getString(request, "chartId", "3m");

NumberFormat decimalFormat = NumberFormat.getNumberInstance(locale);

decimalFormat.setMaximumFractionDigits(2);
decimalFormat.setMinimumFractionDigits(2);
%>

<portlet:renderURL var="convertURL" windowState="<%= WindowState.MAXIMIZED.toString() %>" />

<aui:form action="<%= convertURL %>" cssClass="form-inline" method="post" name="fm">
	<aui:field-wrapper>
		<aui:input autoFocus="<%= windowState.equals(WindowState.MAXIMIZED) %>" inlineField="<%= true %>" label="" name="number" size="3" type="text" value="<%= number %>" />

		<aui:select inlineField="<%= true %>" label="" name="from">

			<%
			for (Map.Entry<String, String> entry : allSymbols.entrySet()) {
				String symbol = entry.getValue();
				String currencyValue = entry.getKey();
			%>

				<aui:option label="<%= currencyValue %>" selected="<%= symbol.equals(from) %>" value="<%= symbol %>" />

			<%
			}
			%>

		</aui:select>

		<liferay-ui:message key="to" />

		<aui:select inlineField="<%= true %>" label="" name="to">

			<%
			for (Map.Entry<String, String> entry : allSymbols.entrySet()) {
				String symbol = entry.getValue();
				String currencyValue = entry.getKey();
			%>

				<aui:option label="<%= currencyValue %>" selected="<%= symbol.equals(to) %>" value="<%= symbol %>" />

			<%
			}
			%>

		</aui:select>

		<aui:button type="submit" value="convert" />
	</aui:field-wrapper>

	<c:choose>
		<c:when test="<%= windowState.equals(WindowState.NORMAL) %>">
			<c:choose>
				<c:when test="<%= symbols.length > 0 %>">
					<table class="table table-bordered table-hover table-striped">
						<thead>
							<tr>
								<th>
									<liferay-ui:message key="currency" />
								</th>

								<%
								for (int i = 0; i < symbols.length; i++) {
									String symbol = symbols[i];
								%>

									<th>
										<liferay-ui:message key='<%= "currency." + symbol %>' /><br />
										(<%= symbol %>)
									</th>

								<%
								}
								%>

							</tr>
						</thead>

						<tbody>

							<%
							for (int i = 0; i < symbols.length; i++) {
								String symbol = symbols[i];
							%>

								<tr>
									<td>
										<%= symbol %>
									</td>

									<%
									for (int j = 0; j < symbols.length; j++) {
										String symbol2 = symbols[j];

										currencyConverter = CurrencyConverterUtil.getCurrencyConverter(symbol2 + symbol);

										if (currencyConverter != null) {
									%>

											<td>
												<c:if test="<%= i != j %>">
													<%= currencyConverter.getRate() %>
												</c:if>

												<c:if test="<%= i == j %>">
													1
												</c:if>
											</td>

									<%
										}
									}
									%>

								</tr>

							<%
							}
							%>

						</tbody>
					</table>
				</c:when>
				<c:otherwise>
					<div class="alert alert-info">
						<a href="<portlet:renderURL portletMode="<%= PortletMode.EDIT.toString() %>" />"><liferay-ui:message key="please-select-a-currency" /></a>
					</div>
				</c:otherwise>
			</c:choose>
		</c:when>
		<c:otherwise>
			<table class="conversion-data table table-bordered">
				<tbody>
					<tr>
						<td class="col-md-4 currency-data">
							<span class="currency-header"><%= currencyConverter.getFromSymbol() %></span>
							<%= number %>
						</td>
						<td class="col-md-4 currency-data">
							<span class="currency-header"><%= currencyConverter.getToSymbol() %></span>
							<%= decimalFormat.format(number * currencyConverter.getRate()) %>
						</td>
						<td class="col-md-4 currency-data">
							<span class="currency-header"><liferay-ui:message key="historical-charts" /></span>

							<%
							PortletURL portletURL = renderResponse.createRenderURL();

							portletURL.setParameter("number", String.valueOf(number));
							portletURL.setParameter("from", currencyConverter.getFromSymbol());
							portletURL.setParameter("to", currencyConverter.getToSymbol());
							%>

							<c:choose>
								<c:when test='<%= chartId.equals("3m") %>'>
									3<liferay-ui:message key="month-abbreviation" />,
								</c:when>
								<c:otherwise>

									<%
									portletURL.setParameter("chartId", "3m");
									%>

									<aui:a href="<%= portletURL.toString() %>">3<liferay-ui:message key="month-abbreviation" /></aui:a>,
								</c:otherwise>
							</c:choose>

							<c:choose>
								<c:when test='<%= chartId.equals("1y") %>'>
									1<liferay-ui:message key="year-abbreviation" />,
								</c:when>
								<c:otherwise>

									<%
									portletURL.setParameter("chartId", "1y");
									%>

									<aui:a href="<%= portletURL.toString() %>">1<liferay-ui:message key="year-abbreviation" /></aui:a>,
								</c:otherwise>
							</c:choose>

							<c:choose>
								<c:when test='<%= chartId.equals("2y") %>'>
									2<liferay-ui:message key="year-abbreviation" />
								</c:when>
								<c:otherwise>

									<%
									portletURL.setParameter("chartId", "2y");
									%>

									<aui:a href="<%= portletURL.toString() %>">2<liferay-ui:message key="year-abbreviation" /></aui:a>
								</c:otherwise>
							</c:choose>
						</td>
					</tr>
				</tbody>
			</table>

			<div class="conversion-graph">
				<img class="currency-graph" height="288" src="http://ichart.yahoo.com/z?s=<%= currencyConverter.getSymbol() %>=X&t=<%= HtmlUtil.escape(chartId) %>?" width="512" />
			</div>
		</c:otherwise>
	</c:choose>
</aui:form>